==> haskell-sbv-7.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-sbv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sbv
version: 7.1
id: sbv-7.1-6NqVwzIDXyhErfW15o9vul
key: sbv-7.1-6NqVwzIDXyhErfW15o9vul
license: BSD3
copyright: Levent Erkok, 2010-2017
maintainer: Levent Erkok (erkokl@gmail.com)
stability: Experimental
homepage: http://leventerkok.github.com/sbv/
synopsis: SMT Based Verification: Symbolic Haskell theorem prover using SMT solving.
description:
    Express properties about Haskell programs and automatically prove them using SMT
    (Satisfiability Modulo Theories) solvers.
    .
    For details, please see: <http://leventerkok.github.com/sbv/>
category: Formal Methods, Theorem Provers, Bit vectors, Symbolic Computation, Math, SMT
author: Levent Erkok
exposed: True
indefinite: False
exposed-modules:
    Data.SBV Data.SBV.Control Data.SBV.Dynamic
    Data.SBV.Examples.BitPrecise.BitTricks
    Data.SBV.Examples.BitPrecise.Legato
    Data.SBV.Examples.BitPrecise.MergeSort
    Data.SBV.Examples.BitPrecise.MultMask
    Data.SBV.Examples.BitPrecise.PrefixSum
    Data.SBV.Examples.CodeGeneration.AddSub
    Data.SBV.Examples.CodeGeneration.CRC_USB5
    Data.SBV.Examples.CodeGeneration.Fibonacci
    Data.SBV.Examples.CodeGeneration.GCD
    Data.SBV.Examples.CodeGeneration.PopulationCount
    Data.SBV.Examples.CodeGeneration.Uninterpreted
    Data.SBV.Examples.Crypto.AES Data.SBV.Examples.Crypto.RC4
    Data.SBV.Examples.Existentials.CRCPolynomial
    Data.SBV.Examples.Existentials.Diophantine
    Data.SBV.Examples.Misc.Auxiliary Data.SBV.Examples.Misc.Enumerate
    Data.SBV.Examples.Misc.Floating Data.SBV.Examples.Misc.ModelExtract
    Data.SBV.Examples.Misc.NoDiv0 Data.SBV.Examples.Misc.Word4
    Data.SBV.Examples.Optimization.ExtField
    Data.SBV.Examples.Optimization.LinearOpt
    Data.SBV.Examples.Optimization.Production
    Data.SBV.Examples.Optimization.VM
    Data.SBV.Examples.Polynomials.Polynomials
    Data.SBV.Examples.Puzzles.Birthday Data.SBV.Examples.Puzzles.Coins
    Data.SBV.Examples.Puzzles.Counts
    Data.SBV.Examples.Puzzles.DogCatMouse
    Data.SBV.Examples.Puzzles.Euler185 Data.SBV.Examples.Puzzles.Fish
    Data.SBV.Examples.Puzzles.MagicSquare
    Data.SBV.Examples.Puzzles.NQueens
    Data.SBV.Examples.Puzzles.SendMoreMoney
    Data.SBV.Examples.Puzzles.Sudoku Data.SBV.Examples.Puzzles.U2Bridge
    Data.SBV.Examples.Queries.AllSat
    Data.SBV.Examples.Queries.CaseSplit Data.SBV.Examples.Queries.Enums
    Data.SBV.Examples.Queries.FourFours
    Data.SBV.Examples.Queries.GuessNumber
    Data.SBV.Examples.Queries.Interpolants
    Data.SBV.Examples.Queries.UnsatCore
    Data.SBV.Examples.Uninterpreted.AUF
    Data.SBV.Examples.Uninterpreted.Deduce
    Data.SBV.Examples.Uninterpreted.Function
    Data.SBV.Examples.Uninterpreted.Shannon
    Data.SBV.Examples.Uninterpreted.Sort
    Data.SBV.Examples.Uninterpreted.UISortAllSat Data.SBV.Internals
    Data.SBV.Tools.CodeGen Data.SBV.Tools.GenTest
    Data.SBV.Tools.Polynomial Data.SBV.Tools.STree
hidden-modules: Data.SBV.Core.AlgReals Data.SBV.Core.Concrete
                Data.SBV.Core.Data Data.SBV.Core.Kind Data.SBV.Core.Model
                Data.SBV.Core.Operations Data.SBV.Core.Floating
                Data.SBV.Core.Splittable Data.SBV.Core.Symbolic
                Data.SBV.Control.Query Data.SBV.Control.Types
                Data.SBV.Control.Utils Data.SBV.Compilers.C
                Data.SBV.Compilers.CodeGen Data.SBV.SMT.SMT Data.SBV.SMT.SMTLib
                Data.SBV.SMT.SMTLib2 Data.SBV.SMT.SMTLibNames Data.SBV.SMT.Utils
                Data.SBV.Provers.Prover Data.SBV.Provers.Boolector
                Data.SBV.Provers.CVC4 Data.SBV.Provers.Yices Data.SBV.Provers.Z3
                Data.SBV.Provers.MathSAT Data.SBV.Provers.ABC
                Data.SBV.Utils.Boolean Data.SBV.Utils.Numeric Data.SBV.Utils.TDiff
                Data.SBV.Utils.Lib Data.SBV.Utils.PrettyNum Data.SBV.Utils.SExpr
abi: 5dcd95031bedd0609e18ddeee22b5b33
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/sbv-7.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/sbv-7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/sbv-7.1
hs-libraries: HSsbv-7.1-6NqVwzIDXyhErfW15o9vul
depends:
    base-4.10.0.0 ghc-8.2.1 QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1
    crackNum-1.9-5jXWz844E7YEt3zFZucyQJ template-haskell-2.12.0.0
    array-0.5.2.0 async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc
    containers-0.5.10.2 deepseq-1.4.3.0 directory-1.3.0.2
    filepath-1.4.1.2 time-1.8.0.2 pretty-1.1.3.3 process-1.6.1.0
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    syb-0.7-2rRPTNxBP6YFePrCXw4i2o
    data-binary-ieee754-0.4.4-AeazHSDlclYKQFsNsak7mZ
    generic-deriving-1.11.2-I1hKFTmgsiECj4HOwgPf5J
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             ghc-8.2.1=56ca0e9901536249349e71801a6a1657
             QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1=2c4212a9c69c9d234eb81396b5fd082b
             crackNum-1.9-5jXWz844E7YEt3zFZucyQJ=878905741b688c0da01a6c34778c0040
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             array-0.5.2.0=044554210403f250e868a2183de060a9
             async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc=12ffabdf3957a0bddb91126c0d755daa
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             pretty-1.1.3.3=315e275f7256c4b9cea549968b2fd167
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             syb-0.7-2rRPTNxBP6YFePrCXw4i2o=db83b83263dcafbe734df45ece7027fc
             data-binary-ieee754-0.4.4-AeazHSDlclYKQFsNsak7mZ=699dee630be1aa3756d711a6da98739b
             generic-deriving-1.11.2-I1hKFTmgsiECj4HOwgPf5J=393ed2deec71da0c1085b81731a1b17f
haddock-interfaces: /usr/share/doc/haskell-sbv/html/sbv.haddock
haddock-html: /usr/share/doc/haskell-sbv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sbv-7.2-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-sbv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sbv
version: 7.2
id: sbv-7.2-10jnYtOr8QHGTcxpUVLRwP
key: sbv-7.2-10jnYtOr8QHGTcxpUVLRwP
license: BSD3
copyright: Levent Erkok, 2010-2017
maintainer: Levent Erkok (erkokl@gmail.com)
stability: Experimental
homepage: http://leventerkok.github.com/sbv/
synopsis: SMT Based Verification: Symbolic Haskell theorem prover using SMT solving.
description:
    Express properties about Haskell programs and automatically prove them using SMT
    (Satisfiability Modulo Theories) solvers.
    .
    For details, please see: <http://leventerkok.github.com/sbv/>
category: Formal Methods, Theorem Provers, Bit vectors, Symbolic Computation, Math, SMT
author: Levent Erkok
exposed: True
indefinite: False
exposed-modules:
    Data.SBV Data.SBV.Control Data.SBV.Dynamic
    Data.SBV.Examples.BitPrecise.BitTricks
    Data.SBV.Examples.BitPrecise.Legato
    Data.SBV.Examples.BitPrecise.MergeSort
    Data.SBV.Examples.BitPrecise.MultMask
    Data.SBV.Examples.BitPrecise.PrefixSum
    Data.SBV.Examples.CodeGeneration.AddSub
    Data.SBV.Examples.CodeGeneration.CRC_USB5
    Data.SBV.Examples.CodeGeneration.Fibonacci
    Data.SBV.Examples.CodeGeneration.GCD
    Data.SBV.Examples.CodeGeneration.PopulationCount
    Data.SBV.Examples.CodeGeneration.Uninterpreted
    Data.SBV.Examples.Crypto.AES Data.SBV.Examples.Crypto.RC4
    Data.SBV.Examples.Existentials.CRCPolynomial
    Data.SBV.Examples.Existentials.Diophantine
    Data.SBV.Examples.Misc.Auxiliary Data.SBV.Examples.Misc.Enumerate
    Data.SBV.Examples.Misc.Floating Data.SBV.Examples.Misc.ModelExtract
    Data.SBV.Examples.Misc.NoDiv0 Data.SBV.Examples.Misc.Word4
    Data.SBV.Examples.Optimization.ExtField
    Data.SBV.Examples.Optimization.LinearOpt
    Data.SBV.Examples.Optimization.Production
    Data.SBV.Examples.Optimization.VM
    Data.SBV.Examples.Polynomials.Polynomials
    Data.SBV.Examples.Puzzles.Birthday Data.SBV.Examples.Puzzles.Coins
    Data.SBV.Examples.Puzzles.Counts
    Data.SBV.Examples.Puzzles.DogCatMouse
    Data.SBV.Examples.Puzzles.Euler185 Data.SBV.Examples.Puzzles.Fish
    Data.SBV.Examples.Puzzles.MagicSquare
    Data.SBV.Examples.Puzzles.NQueens
    Data.SBV.Examples.Puzzles.SendMoreMoney
    Data.SBV.Examples.Puzzles.Sudoku Data.SBV.Examples.Puzzles.U2Bridge
    Data.SBV.Examples.Queries.AllSat
    Data.SBV.Examples.Queries.CaseSplit Data.SBV.Examples.Queries.Enums
    Data.SBV.Examples.Queries.FourFours
    Data.SBV.Examples.Queries.GuessNumber
    Data.SBV.Examples.Queries.Interpolants
    Data.SBV.Examples.Queries.UnsatCore
    Data.SBV.Examples.Uninterpreted.AUF
    Data.SBV.Examples.Uninterpreted.Deduce
    Data.SBV.Examples.Uninterpreted.Function
    Data.SBV.Examples.Uninterpreted.Shannon
    Data.SBV.Examples.Uninterpreted.Sort
    Data.SBV.Examples.Uninterpreted.UISortAllSat Data.SBV.Internals
    Data.SBV.Tools.CodeGen Data.SBV.Tools.GenTest
    Data.SBV.Tools.Polynomial Data.SBV.Tools.STree
hidden-modules: Data.SBV.Core.AlgReals Data.SBV.Core.Concrete
                Data.SBV.Core.Data Data.SBV.Core.Kind Data.SBV.Core.Model
                Data.SBV.Core.Operations Data.SBV.Core.Floating
                Data.SBV.Core.Splittable Data.SBV.Core.Symbolic
                Data.SBV.Control.Query Data.SBV.Control.Types
                Data.SBV.Control.Utils Data.SBV.Compilers.C
                Data.SBV.Compilers.CodeGen Data.SBV.SMT.SMT Data.SBV.SMT.SMTLib
                Data.SBV.SMT.SMTLib2 Data.SBV.SMT.SMTLibNames Data.SBV.SMT.Utils
                Data.SBV.Provers.Prover Data.SBV.Provers.Boolector
                Data.SBV.Provers.CVC4 Data.SBV.Provers.Yices Data.SBV.Provers.Z3
                Data.SBV.Provers.MathSAT Data.SBV.Provers.ABC
                Data.SBV.Utils.Boolean Data.SBV.Utils.Numeric Data.SBV.Utils.TDiff
                Data.SBV.Utils.Lib Data.SBV.Utils.PrettyNum Data.SBV.Utils.SExpr
abi: 29bc5c3c0b0b2688f8fe9c6e1b430fba
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/sbv-7.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/sbv-7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/sbv-7.2
hs-libraries: HSsbv-7.2-10jnYtOr8QHGTcxpUVLRwP
depends:
    base-4.10.0.0 ghc-8.2.1 QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1
    crackNum-1.9-5jXWz844E7YEt3zFZucyQJ template-haskell-2.12.0.0
    array-0.5.2.0 async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc
    containers-0.5.10.2 deepseq-1.4.3.0 directory-1.3.0.2
    filepath-1.4.1.2 time-1.8.0.2 pretty-1.1.3.3 process-1.6.1.0
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    syb-0.7-2rRPTNxBP6YFePrCXw4i2o
    data-binary-ieee754-0.4.4-AeazHSDlclYKQFsNsak7mZ
    generic-deriving-1.11.2-I1hKFTmgsiECj4HOwgPf5J
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             ghc-8.2.1=56ca0e9901536249349e71801a6a1657
             QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1=2c4212a9c69c9d234eb81396b5fd082b
             crackNum-1.9-5jXWz844E7YEt3zFZucyQJ=878905741b688c0da01a6c34778c0040
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             array-0.5.2.0=044554210403f250e868a2183de060a9
             async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc=12ffabdf3957a0bddb91126c0d755daa
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             pretty-1.1.3.3=315e275f7256c4b9cea549968b2fd167
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             syb-0.7-2rRPTNxBP6YFePrCXw4i2o=db83b83263dcafbe734df45ece7027fc
             data-binary-ieee754-0.4.4-AeazHSDlclYKQFsNsak7mZ=699dee630be1aa3756d711a6da98739b
             generic-deriving-1.11.2-I1hKFTmgsiECj4HOwgPf5J=393ed2deec71da0c1085b81731a1b17f
haddock-interfaces: /usr/share/doc/haskell-sbv/html/sbv.haddock
haddock-html: /usr/share/doc/haskell-sbv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
